@@ -1,23 +1,24 @@
-import uuid
-import random
-import time
+
 import os
 
-from unittest import mock
 from collections import namedtuple
 
 os.environ.setdefault("DJANGO_SETTINGS_MODULE", "settings")
 from django.test import TestCase
+
 # from data.models import *
 # from Analyzer import Analyzer
 # from Updater import Updater
-from mc3_integration.test.FakeData import FakeDataGenerator
-from mc3_integration.poller import PollingThread, ORMFetcher
-from queue import Queue, Empty
-from datetime import datetime
+from cleargrid.mc3_integration.test.FakeData import FakeDataGenerator
+from cleargrid.mc3_integration.poller import PollingThread, ORMFetcher
+from queue import Queue
 
 
-Row = namedtuple("Row", ["identifier", "timeoccurred", "latitude", "longitude", "dl_requests"])
+Row = namedtuple(
+    "Row",
+    ["identifier", "timeoccurred", "latitude", "longitude", "dl_requests"],
+)
+
 
 class MockORMFetcher:
     def __init__(self):
@@ -31,7 +32,7 @@ class MockORMFetcher:
 
     @property
     def meters_updated(self) -> int:
-        '''Returns if a new meter exists'''
+        """Returns if a new meter exists"""
         return self._updated
 
     @property
@@ -60,8 +61,9 @@ class TestPoller(TestCase):
         """
         self.result_q = Queue()
         self.mock_orm_fetcher = MockORMFetcher()
-        self.poller = PollingThread(None, result_q=self.result_q, fetcher=self.mock_orm_fetcher)
-
+        self.poller = PollingThread(
+            None, result_q=self.result_q, fetcher=self.mock_orm_fetcher
+        )
 
     def test_empty_poller(self):
         self.poller.process()
@@ -71,85 +73,216 @@ class TestPoller(TestCase):
         # Run through an initial cycle
         self.poller.process()
         # Add meters and update
-        self.mock_orm_fetcher.set_meter([Row(identifier='66052082', latitude='51.208463', longitude='-112.903899', dl_requests=1, timeoccurred=None), 
-                                        Row(identifier='42181791', latitude='51.290495', longitude='-113.006506', dl_requests=1, timeoccurred=None), 
-                                        ]
-                                    )
+        self.mock_orm_fetcher.set_meter(
+            [
+                Row(
+                    identifier="66052082",
+                    latitude="51.208463",
+                    longitude="-112.903899",
+                    dl_requests=1,
+                    timeoccurred=None,
+                ),
+                Row(
+                    identifier="42181791",
+                    latitude="51.290495",
+                    longitude="-113.006506",
+                    dl_requests=1,
+                    timeoccurred=None,
+                ),
+            ]
+        )
         self.mock_orm_fetcher._updated = 2
         self.poller.process()
         # Check the Queue
         command, data = self.result_q.get()
         map_command, map_data = self.result_q.get()
-        required_output = {'66052082': {'identifier': '66052082', 'latitude': '51.208463', 'longitude': '-112.903899', 'realtime': [], 'logging': []}, 
-                            '42181791': {'identifier': '42181791', 'latitude': '51.290495', 'longitude': '-113.006506', 'realtime': [], 'logging': []}}
-        map_required_output = {'66052082': {'identifier': '66052082', 'latitude': '51.208463', 'longitude': '-112.903899', 'realtime': [], 'logging': []}, 
-                                '42181791': {'identifier': '42181791', 'latitude': '51.290495', 'longitude': '-113.006506', 'realtime': [], 'logging': []}}
-        self.assertEqual(command, 'add_meters')
+        required_output = {
+            "66052082": {
+                "identifier": "66052082",
+                "latitude": "51.208463",
+                "longitude": "-112.903899",
+                "realtime": [],
+                "logging": [],
+            },
+            "42181791": {
+                "identifier": "42181791",
+                "latitude": "51.290495",
+                "longitude": "-113.006506",
+                "realtime": [],
+                "logging": [],
+            },
+        }
+        map_required_output = {
+            "66052082": {
+                "identifier": "66052082",
+                "latitude": "51.208463",
+                "longitude": "-112.903899",
+                "realtime": [],
+                "logging": [],
+            },
+            "42181791": {
+                "identifier": "42181791",
+                "latitude": "51.290495",
+                "longitude": "-113.006506",
+                "realtime": [],
+                "logging": [],
+            },
+        }
+        self.assertEqual(command, "add_meters")
         self.assertEqual(data, required_output)
-        self.assertEqual(map_command, 'update_map')
+        self.assertEqual(map_command, "update_map")
         self.assertEqual(map_data, map_required_output)
-
-
-    def test_new_scm(self): 
+    def test_new_scm(self):
         # Run through an initial cycle
         self.poller.process()
         # Add meters and update
-        self.mock_orm_fetcher.set_meter([Row(identifier='66052082', latitude='51.208463', longitude='-112.903899', dl_requests=1, timeoccurred=None), 
-                                        Row(identifier='42181791', latitude='51.290495', longitude='-113.006506', dl_requests=1, timeoccurred=None), 
-                                        ]
-                                    )
+        self.mock_orm_fetcher.set_meter(
+            [
+                Row(
+                    identifier="66052082",
+                    latitude="51.208463",
+                    longitude="-112.903899",
+                    dl_requests=1,
+                    timeoccurred=None,
+                ),
+                Row(
+                    identifier="42181791",
+                    latitude="51.290495",
+                    longitude="-113.006506",
+                    dl_requests=1,
+                    timeoccurred=None,
+                ),
+            ]
+        )
         self.mock_orm_fetcher._updated = 2
         self.poller.process()
         # Clear the queue
         while not self.result_q.empty():
             self.result_q.get()
- 
+
         # Add scm readings
-        self.mock_orm_fetcher._realtime_messages = [Row(identifier='66052082', latitude='51.208463', longitude='-112.903899', dl_requests=1, timeoccurred=datetime(2019, 7, 2, 14, 46, 11, 760000)), 
-                                                    Row(identifier='42181791', latitude='51.290495', longitude='-113.006506', dl_requests=1, timeoccurred=datetime(2019, 7, 2, 15, 12, 8, 167000))]
+        self.mock_orm_fetcher._realtime_messages = [
+            Row(
+                identifier="66052082",
+                latitude="51.208463",
+                longitude="-112.903899",
+                dl_requests=1,
+                timeoccurred=datetime(2019, 7, 2, 14, 46, 11, 760000),
+            ),
+            Row(
+                identifier="42181791",
+                latitude="51.290495",
+                longitude="-113.006506",
+                dl_requests=1,
+                timeoccurred=datetime(2019, 7, 2, 15, 12, 8, 167000),
+            ),
+        ]
         self.poller.process()
 
-        #Check the queue
+        # Check the queue
         reading_command, reading_data = self.result_q.get()
         map_command, map_data = self.result_q.get()
-        required_output = {'66052082': [('scm', 1562100371.76)], '42181791': [('scm', 1562101928.167)]}
-        map_required_output = { '66052082': {'identifier': '66052082', 'latitude': '51.208463', 'longitude': '-112.903899', 'realtime': [('scm', 1562100371.76)], 'logging': []}, 
-                                '42181791': {'identifier': '42181791', 'latitude': '51.290495', 'longitude': '-113.006506', 'realtime': [('scm', 1562101928.167)], 'logging': []}}
-        self.assertEqual(reading_command, 'update_readings')
+        required_output = {
+            "66052082": [("scm", 1562100371.76)],
+            "42181791": [("scm", 1562101928.167)],
+        }
+        map_required_output = {
+            "66052082": {
+                "identifier": "66052082",
+                "latitude": "51.208463",
+                "longitude": "-112.903899",
+                "realtime": [("scm", 1562100371.76)],
+                "logging": [],
+            },
+            "42181791": {
+                "identifier": "42181791",
+                "latitude": "51.290495",
+                "longitude": "-113.006506",
+                "realtime": [("scm", 1562101928.167)],
+                "logging": [],
+            },
+        }
+        self.assertEqual(reading_command, "update_readings")
         self.assertEqual(reading_data, required_output)
-        self.assertEqual(map_command, 'update_map')
+        self.assertEqual(map_command, "update_map")
         self.assertEqual(map_data, map_required_output)
 
-    def test_new_idm(self): 
+    def test_new_idm(self):
         # Run through an initial cycle
         self.poller.process()
         # Add meters and update
-        self.mock_orm_fetcher.set_meter([Row(identifier='66052082', latitude='51.208463', longitude='-112.903899', dl_requests=1, timeoccurred=None), 
-                                        Row(identifier='42181791', latitude='51.290495', longitude='-113.006506', dl_requests=1, timeoccurred=None), 
-                                        ]
-                                    )
+        self.mock_orm_fetcher.set_meter(
+            [
+                Row(
+                    identifier="66052082",
+                    latitude="51.208463",
+                    longitude="-112.903899",
+                    dl_requests=1,
+                    timeoccurred=None,
+                ),
+                Row(
+                    identifier="42181791",
+                    latitude="51.290495",
+                    longitude="-113.006506",
+                    dl_requests=1,
+                    timeoccurred=None,
+                ),
+            ]
+        )
         self.mock_orm_fetcher._updated = 2
         self.poller.process()
         # Clear the queue
         while not self.result_q.empty():
             self.result_q.get()
- 
+
         # Add scm readings
-        self.mock_orm_fetcher._logging_messages = [Row(identifier='66052082', latitude='51.208463', longitude='-112.903899', dl_requests=1, timeoccurred=datetime(2019, 7, 2, 14, 46, 11, 760000)), 
-                                                    Row(identifier='42181791', latitude='51.290495', longitude='-113.006506', dl_requests=1, timeoccurred=datetime(2019, 7, 2, 15, 12, 8, 167000))]
+        self.mock_orm_fetcher._logging_messages = [
+            Row(
+                identifier="66052082",
+                latitude="51.208463",
+                longitude="-112.903899",
+                dl_requests=1,
+                timeoccurred=datetime(2019, 7, 2, 14, 46, 11, 760000),
+            ),
+            Row(
+                identifier="42181791",
+                latitude="51.290495",
+                longitude="-113.006506",
+                dl_requests=1,
+                timeoccurred=datetime(2019, 7, 2, 15, 12, 8, 167000),
+            ),
+        ]
         self.poller.process()
 
-        #Check the queue
+        # Check the queue
         reading_command, reading_data = self.result_q.get()
         map_command, map_data = self.result_q.get()
-        required_output = {'66052082': [('idm', 1562100371.76)], '42181791': [('idm', 1562101928.167)]}
-        map_required_output ={  '66052082': {'identifier': '66052082', 'latitude': '51.208463', 'longitude': '-112.903899', 'realtime': [], 'logging': [('idm', 1562100371.76)]}, 
-                                '42181791': {'identifier': '42181791', 'latitude': '51.290495', 'longitude': '-113.006506', 'realtime': [], 'logging': [('idm', 1562101928.167)]}}
-        self.assertEqual(reading_command, 'update_readings')
+        required_output = {
+            "66052082": [("idm", 1562100371.76)],
+            "42181791": [("idm", 1562101928.167)],
+        }
+        map_required_output = {
+            "66052082": {
+                "identifier": "66052082",
+                "latitude": "51.208463",
+                "longitude": "-112.903899",
+                "realtime": [],
+                "logging": [("idm", 1562100371.76)],
+            },
+            "42181791": {
+                "identifier": "42181791",
+                "latitude": "51.290495",
+                "longitude": "-113.006506",
+                "realtime": [],
+                "logging": [("idm", 1562101928.167)],
+            },
+        }
+        self.assertEqual(reading_command, "update_readings")
         self.assertEqual(reading_data, required_output)
-        self.assertEqual(map_command, 'update_map')
+        self.assertEqual(map_command, "update_map")
         self.assertEqual(map_data, map_required_output)
 
+
 class TestORMFetcher(TestCase):
     def setUp(self):
         """
@@ -160,7 +293,7 @@ class TestORMFetcher(TestCase):
         """
         self.orm_fetcher = ORMFetcher()
         self.fake_data_generator = FakeDataGenerator()
-    
+
     def test_meters_updated(self):
         # Count initial database data
         self.orm_fetcher.meters_updated
@@ -171,7 +304,6 @@ class TestORMFetcher(TestCase):
         # If we check again, it should be false
         self.assertFalse(self.orm_fetcher.meters_updated)
 
-
     def test_realtime_messages(self):
         # Get initial messages (empty list)
         messages = self.orm_fetcher.realtime_messages
@@ -185,11 +317,15 @@ class TestORMFetcher(TestCase):
         messages = self.orm_fetcher.realtime_messages
 
         # Assertion
-        self.assertEqual(messages[0].timeoccurred, self.orm_fetcher.last_realtime_fetch, generated_reading.timeoccurred)
+        self.assertEqual(
+            messages[0].timeoccurred,
+            self.orm_fetcher.last_realtime_fetch,
+            generated_reading.timeoccurred,
+        )
         self.assertEqual(str(meter.identifier), messages[0].identifier)
-    
+
     def test_logging_messages(self):
-    # Get initial messages (empty list)
+        # Get initial messages (empty list)
         messages = self.orm_fetcher.logging_messages
         self.assertFalse(messages)
 
@@ -202,13 +338,19 @@ class TestORMFetcher(TestCase):
         self.assertFalse(messages)
 
         # Generate Reading
-        generated_dlreading = self.fake_data_generator.create_extendeddlReading(generated_request)
+        generated_dlreading = self.fake_data_generator.create_extendeddlReading(
+            generated_request
+        )
 
         # Get updated messages
         messages = self.orm_fetcher.logging_messages
 
         # Assertion
-        self.assertEqual(messages[0].timeoccurred, self.orm_fetcher.last_logging_fetch, generated_dlreading.timeoccurred)
+        self.assertEqual(
+            messages[0].timeoccurred,
+            self.orm_fetcher.last_logging_fetch,
+            generated_dlreading.timeoccurred,
+        )
         self.assertEqual(str(meter.identifier), messages[0].identifier)
 
 
@@ -218,7 +360,7 @@ class TestORMFetcher(TestCase):
 #         This is set up for every test
 #             1. Stub the data
 #             2. Initialize the Analyzer
-#             3. Create a random ENDPOINT, 
+#             3. Create a random ENDPOINT,
 #         """
 #         self.requests_mock = mock.patch("Updater.requests.post")
 #         self.requests_patch = self.requests_mock.start()
@@ -359,4 +501,3 @@ class TestORMFetcher(TestCase):
 
 if __name__ == "__main__":
     unittest.main()
-
